/*
		                 LCRZOEX
                             Network toolbox
             Copyright(c) 1999,2000,2001,2002 Laurent Constantin
                                  -----

  Main server    : http://www.laurentconstantin.com/
  Backup servers : http://go.to/laurentconstantin/
                   http://laurentconstantin.est-la.com/
                   http://laurentconstantin.free.fr/
                   http://membres.lycos.fr/lauconstantin/
  [my current email address is on the web servers]

                                  -----
  This file is part of Lcrzoex.

  Lcrzoex is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Lcrzoex is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <lcrzo.h>
#include "lcrzoex.h"
#include "lcrzoex__00001.h"
#include "lcrzoex__00002.h"
#include "lcrzoex__00003.h"
#include "lcrzoex__00004.h"
#include "lcrzoex__00005.h"
#include "lcrzoex__00006.h"
#include "lcrzoex__00007.h"
#include "lcrzoex__00008.h"

/*-------------------------------------------------------------*/
/* function declaration */
int main(int argc, char* argv[]);
int lcrzoexmain(int argc, char* argv[]);
int lcrzoex_check_ending_number(lcrzo_conststring progname,
                                lcrzo_bool *phasanendingnumber,
                                lcrzo_uint32 *ptoolnumber);
int lcrzoex_helpchoice(lcrzo_conststring progname);
int lcrzoex_helpchoice_tool_cat(lcrzo_int16 language);
int lcrzoex_helpchoice_tool_subcat(lcrzo_int16 language);
int lcrzoex_helpchoice_tool_choose(lcrzo_int16 language,
				   lcrzo_string levels,
				   lcrzo_int16 level,
				   lcrzo_uint32 minnum,
				   lcrzo_uint32 maxnum,
				   lcrzo_uint32 *ptoolnumber);
int lcrzoex_helpchoice_tool_list(lcrzo_string levels, 
				 lcrzo_uint32 *ptoolnumber);
int lcrzoex_helpchoice_subcat(lcrzo_int16 language);
int lcrzoex_helpchoice_subcat_choose(lcrzo_int16 language,
				     lcrzo_string levels,
				     lcrzo_int16 level,
				     char lastchar,
				     lcrzo_uint8 *pchoice);

/*-------------------------------------------------------------*/
/* main function */
int main(int argc, char* argv[])
{ int ret;

  /* initialize lcrzo */
  lcrzo_init(); 

  /* to check lcrzo compilation parameters*/
  lcrzo_epr(lcrzo_compilparam_check());

  /* if you want to change language */
  /*lcrzo_epr(lcrzo_global_set_language(LCRZO_GLOBAL_LANG_FR));*/
  /*lcrzo_epr(lcrzo_global_set_language(LCRZO_GLOBAL_LANG_EN));*/

  /* the real main function */
  ret=lcrzoexmain(argc, argv);
  
  /* close lcrzo */
  lcrzo_close();
  return(ret);
}

/*-------------------------------------------------------------*/
int lcrzoexmain(int argc, char* argv[])
{ lcrzo_uint32 toolnumber;
  lcrzo_int16 language;
  lcrzo_bool hasanendingnumber;
  int ac, ret;
  char **av;
  
  /* add error displaying functions */
  lcrzo_epr(lcrzo_global_set_err_displayfunction(&lcrzoex_err_print));

  /* get the current language */
  lcrzo_epr(lcrzo_global_get_language(&language));

  /* check if the program contains an ending number */
  lcrzo_epr(lcrzoex_check_ending_number(argv[0], &hasanendingnumber,
					&toolnumber));

  /* if it does not end with a number, read it from the command line */
  if (!hasanendingnumber)
  { /* we help user to choose the tool he wants */
    if ( argc==1 )
    { return(lcrzoex_helpchoice(argv[0]));
    }
    lcrzo_epr(lcrzo_uint32_init_text(argv[1], &toolnumber));
    ac=argc-1;
    av=argv+1;
  }
  else
  { ac=argc;
    av=argv;
  }

  /* call the wanted tool */
  ret=LCRZO_ERR_OK;
  if ( toolnumber>=1 && toolnumber<=50 )
  { ret=lcrzoex__00001_main(ac, av, toolnumber);
  }
  else if ( toolnumber>=51 && toolnumber<=100 )
  { ret=lcrzoex__00002_main(ac, av, toolnumber);
  }
  else if ( toolnumber>=101 && toolnumber<=150 )
  { ret=lcrzoex__00003_main(ac, av, toolnumber);
  }
  else if ( toolnumber>=151 && toolnumber<=200 )
  { ret=lcrzoex__00004_main(ac, av, toolnumber);
  }
  else if ( toolnumber>=201 && toolnumber<=250 )
  { ret=lcrzoex__00005_main(ac, av, toolnumber);
  }
  else if ( toolnumber>=251 && toolnumber<=300 )
  { ret=lcrzoex__00006_main(ac, av, toolnumber);
  }
  else if ( toolnumber>=301 && toolnumber<=350 )
  { ret=lcrzoex__00007_main(ac, av, toolnumber);
  }
  else if ( toolnumber>=351 && toolnumber<=400 )
  { ret=lcrzoex__00008_main(ac, av, toolnumber);
  }
  else 
  { shared_lcrzoex_unknowntool_print(toolnumber);
    return(LCRZO_ERR_OK);
  }

  /* reinit lcrzo because tools might have closed it */
  lcrzo_init();
  lcrzo_epr(lcrzo_global_set_err_displayfunction(&lcrzoex_err_print));
  lcrzo_ep(ret);

  return(ret);
}

/*-------------------------------------------------------------*/
int lcrzoex_check_ending_number(lcrzo_conststring progname,
                                lcrzo_bool *phasanendingnumber,
                                lcrzo_uint32 *ptoolnumber)
{ lcrzo_conststring pc;
  char c;
  int ret, i;

  if (phasanendingnumber!=NULL) *phasanendingnumber=LCRZO_FALSE;

  /* program name is too short */
  if (!strlen(progname)) return(LCRZO_ERR_OK);

  /* does not end with a digit, so exit now */
  c=progname[strlen(progname)-1];
  if ( c<'0' || c>'9' ) return(LCRZO_ERR_OK);

  /* find the position of the first non digit character */
  pc=progname;
  for ( i=strlen(progname)-1 ; i>=0 ; i-- )
  { c=progname[i];
    if ( c<'0' || c>'9' )
    { pc=progname+i+1;
      break;
    }
  }
  
  /* now, remove leading zeros */
  while ( strlen(pc) )
  { if ( *pc=='0' ) pc++;
    else break;
  }

  /* try to convert to a number */
  ret=lcrzo_uint32_init_text(pc, ptoolnumber);
  if ( ret==LCRZO_ERR_OK)
  { if (phasanendingnumber!=NULL) *phasanendingnumber=LCRZO_TRUE;
  }

  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int lcrzoex_helpchoice_tool_list(lcrzo_string levels, 
				 lcrzo_uint32 *ptoolnumber)
{ lcrzo_uint32 toolnumber;
  lcrzo_int16 language, level;
  shared_lcrzoex_helpmode_cat cat;
  shared_lcrzoex_helpmode_catheader catheader;

  /* get the current language */
  lcrzo_epr(lcrzo_global_get_language(&language));

  level=1;
  toolnumber=0;
  switch(levels[level]) { 
  case '\0':
    lcrzo_epr(shared_lcrzoex_helpmode_mainmenu(language, levels));
    break;

  case 'a' :
    lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000157));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000155));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000002));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000274));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000029));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000032));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000037));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000040));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000048));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000051));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000065));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000068));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000170));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000092));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000168));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000186));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000116));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000182));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000141));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000151));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000172));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
    break;
    
  case 'b' :
    level++;
    switch(levels[level]) { 
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
#define C_H(f,e) shared_lcrzoex_helpmode_catheader_add(&catheader,f,e)
      lcrzo_epr(C_H("informations sur cette machine",
		    "information on this computer"));
      lcrzo_epr(C_H("informations sur une machine distante",
		    "information on other computers"));
      lcrzo_epr(C_H("informations sur un reseau",
		    "information on this network"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader,
							levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000001));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000005));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000006));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000154));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000155));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000157));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000158));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000159));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000160));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000173));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000174));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000175));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000278));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000002));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000156));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000003));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000004));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000176));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000379));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000380));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000381));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000134));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000209));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000210));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000211));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000212));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'c' :
    level++;
    switch(levels[level]) { 
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("sniffe des paquets et les affiche",
		    "sniff packets and print them"));
      lcrzo_epr(C_H("sniffe des paquets et les sauve",
		    "sniff packets and save them"));
      lcrzo_epr(C_H("sniffe des paquets et verifie leur checksum",
		    "sniff packets and verify checksum"));
      lcrzo_epr(C_H("sniffe des paquets et les compte", 
		    "sniff packets and count them"));
      lcrzo_epr(C_H("sniffe des paquets et cherche des donnees", 
		    "sniff packets and search data"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader,
							levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000007));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000274));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000275));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000008));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000009));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000295));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000296));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000297));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000364));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000370));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000010));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000011));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000012));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000013));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000014));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000015));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000365));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000016));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000017));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000018));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'd' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000019));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000020));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000021));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'e' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000353));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000354));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000355));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000356));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'd' :
    lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000022));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000027));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000035));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000046));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000063));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000023));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000221));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000222));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000223));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000224));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000225));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000028));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000226));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000227));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000228));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000229));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000230));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000231));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000232));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000233));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000234));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000036));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000235));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000236));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000237));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000047));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000238));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000239));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000240));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000064));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000241));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000242));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000243));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000258));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000259));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
    break;
    
  case 'e' :
    level++;
    switch(levels[level]) { 
    case '\0': 
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("spoof ethernet",
		    "ethernet spoof"));
      lcrzo_epr(C_H("spoof ip",
		    "ip spoof"));
      lcrzo_epr(C_H("spoof udp",
		    "udp spoof"));
      lcrzo_epr(C_H("spoof tcp",
		    "tcp spoof"));
      lcrzo_epr(C_H("spoof icmp",
		    "icmp spoof"));
      lcrzo_epr(C_H("spoof arp/rarp",
		    "arp/rarp spoof"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader,
							levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000024));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000025));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000026));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000136));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000029));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000298));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000030));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000031));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000164));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000032));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000299));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000033));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000034));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      level++;
      switch(levels[level]) { 
      case '\0':
	lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
							 language, level));
	lcrzo_epr(C_H("spoof udp generique",
		      "generic udp spoof"));
	lcrzo_epr(C_H("spoof udp syslog",
		      "syslog udp spoof"));
	lcrzo_epr(C_H("spoof udp dns",
		      "dns udp spoof"));
	lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader,
							  levels));
	break;
      case 'a' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000037));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000300));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000038));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000039));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000040));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000301));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000041));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000042));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000135));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels,&toolnumber));
	break;
      case 'b' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000043));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000044));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000045));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels,&toolnumber));
	break;
      case 'c' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000327));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000328));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000329));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000330));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000331));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000332));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000333));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000334));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000335));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000336));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000337));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000338));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000339));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000340));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels,&toolnumber));
	break;
      }
      break;
    case 'd' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000048));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000302));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000049));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000306));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000204));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000050));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000205));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000051));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000303));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000052));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000307));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000206));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000053));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000207));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000054));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000055));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000056));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000057));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000058));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000059));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000060));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000061));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000062));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'e' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000065));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000304));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000066));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000067));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000068));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000305));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000069));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000070));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000071));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000072));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000073));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000074));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000075));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000076));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000077));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000078));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000079));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'f' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000080));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000081));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000082));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000083));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000208));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'f' :
    level++;
    switch(levels[level]) { 
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("clients udp interactifs",
		    "udp interactive clients"));
      lcrzo_epr(C_H("clients syslog",
		    "syslog clients"));
      lcrzo_epr(C_H("clients dns",
		    "dns clients"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000084));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000308));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000085));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000168));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000309));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000178));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000086));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000087));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000169));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000179));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000088));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000089));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000090));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000091));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000341));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000344));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
      /* jump to this section */
      /*strcpy(levels, "-ecc");
	level=3;
	break;*/
    }
    break;

  case 'g' :
    level++;
    switch(levels[level]) { 
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("clients tcp interactifs",
		    "tcp interactive clients"));
      lcrzo_epr(C_H("clients tcp affichant la banniere d'accueil du serveur",
		    "clients displaying servers' banner"));
      lcrzo_epr(C_H("clients HTTP (web)",
		    "HTTP (web) clients"));
      lcrzo_epr(C_H("clients FTP",
		    "FTP clients"));
      lcrzo_epr(C_H("clients SMTP (mail)",
		    "SMTP (email) clients"));
      lcrzo_epr(C_H("clients NNTP (newsgroup)",
		    "NNTP (newsgroup) clients"));
      lcrzo_epr(C_H("clients TELNET",
		    "TELNET clients"));
      lcrzo_epr(C_H("clients DNS",
		    "DNS clients"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000092));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000312));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000093));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000167));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000170));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000313));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000180));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000094));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000095));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000171));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000181));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000100));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000101));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000102));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000103));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000137));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      level++;
      switch(levels[level]) {
      case '\0':
        lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
							 language, level));
	lcrzo_epr(C_H("affiche une page HTML",
		      "display an HTML page"));
	lcrzo_epr(C_H("telecharge une page HTML",
		      "download an HTML page"));
	lcrzo_epr(C_H("telecharge un site (web spider)",
		      "download a web site (web spider)"));
	lcrzo_epr(C_H("divers",
		      "miscellaneous"));
	lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
	break;
      case 'a' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000096));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000097));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000190));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000194));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000098));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000099));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000191));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000195));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat,levels,&toolnumber));
	break;
      case 'b' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000294));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000192));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000196));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000193));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000197));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat,levels,&toolnumber));
	break;
      case 'c' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000360));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000361));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000362));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat,levels,&toolnumber));
	break;
      case 'd' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000198));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000200));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000202));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000199));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000201));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000203));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000359));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat,levels,&toolnumber));
	break;
      }
      break;
    case 'd' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000104));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000105));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000279));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000281));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000283));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000285));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000287));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000106));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000107));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000280));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000282));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000284));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000286));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000288));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000165));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000268));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000289));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000290));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000291));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000292));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'e' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000162));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000166));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000261));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000262));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000264));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'f' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000163));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000263));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000265));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000266));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000267));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000293));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'g' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000270));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000271));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000272));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000273));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'h' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000342));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000343));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'h' :
    level++;
    switch(levels[level]) {
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("serveurs udp interactifs",
		    "udp interactive servers"));
      lcrzo_epr(C_H("serveurs udp monoclient",
		    "udp monoclient servers"));
      lcrzo_epr(C_H("serveurs udp multiclient",
		    "udp multiclient servers"));
      lcrzo_epr(C_H("serveurs DNS",
		    "DNS servers"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000108));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000310));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000109));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000182));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000311));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000183));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000110));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000111));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000184));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000185));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000112));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000113));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000114));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000115));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000124));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000125));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000346));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000126));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000347));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'd' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000345));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000348));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000349));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000350));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'i' :
    level++;
    switch(levels[level]) {
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("serveurs tcp interactifs",
		    "tcp interactive servers"));
      lcrzo_epr(C_H("serveurs tcp renvoyant les donnees recues",
		    "tcp servers echoing received data"));
      lcrzo_epr(C_H("serveurs web",
		    "web servers"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000116));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000314));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000117));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000186));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000315));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000187));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000118));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000119));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000188));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000189));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000120));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000121));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000122));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000123));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000127));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000128));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000260));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000277));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000358));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'j' :
    lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000213));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000214));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000352));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
    break;
    
  case 'k' :
    lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000131));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000138));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000172));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000316));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000244));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000245));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000317));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000246));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000247));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000318));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000208));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000248));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000249));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000319));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000250));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000251));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000320));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000177));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
    break;
    
  case 'l' :
    lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000216));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000276));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000217));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000218));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000219));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000220));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000260));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000277));
    lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
    break;
    
  case 'm' :
    level++;
    switch(levels[level]) {
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("attaque reseau",
		    "network attacks"));
      lcrzo_epr(C_H("email usurpe",
		    "spoofed email"));
      lcrzo_epr(C_H("attaque brute force",
		    "brute force attack"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
      break;
    case 'a' :
      level++;
      switch(levels[level]) {
      case '\0':
	lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
							 language, level));
	lcrzo_epr(C_H("scanning",
		      "scanning"));
	lcrzo_epr(C_H("attaques Ethernet",
		      "Ethernet attacks"));
	lcrzo_epr(C_H("attaques ARP",
		      "ARP attacks"));
	lcrzo_epr(C_H("attaques ICMP",
		      "ICMP attacks"));
	lcrzo_epr(C_H("attaques TCP",
		      "TCP attacks"));
	lcrzo_epr(C_H("attaques DNS",
		      "DNS attacks"));
	lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
	break;
      case 'a' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000252));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000253));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000322));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000254));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000255));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000323));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000256));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000257));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000324));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, 
						    &toolnumber));
	break;
      case 'b' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000357));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000369));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, 
						    &toolnumber));
	break;
      case 'c' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000130));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000131));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000215));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000081));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000367));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, 
						    &toolnumber));
	break;
      case 'd' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000374));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000375));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000376));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000377));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000378));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, 
						    &toolnumber));
	break;
      case 'e' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000129));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000132));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000371));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000269));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000133));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000321));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, 
						    &toolnumber));
	break;
      case 'f' :
	lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000345));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000349));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000368));
	lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, 
						    &toolnumber));
	break;
      }
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000166));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000262));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000264));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000202));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000203));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000268));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000273));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'n' :
    level++;
    switch(levels[level]) { 
    case '\0':
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_init(&catheader,
						       language, level));
      lcrzo_epr(C_H("conversion de nombres et caracteres",
		    "conversion of numbers and characters"));
      lcrzo_epr(C_H("conversion d'adresse IP",
		    "conversion of IP addresses"));
      lcrzo_epr(C_H("conversion de chaines",
		    "conversion of strings"));
      lcrzo_epr(C_H("manipulation de fichiers",
		    "conversion and dump of files"));
      lcrzo_epr(C_H("specifique a lcrzoex",
		    "specific to lcrzoex"));
      lcrzo_epr(shared_lcrzoex_helpmode_catheader_close(&catheader, levels));
      break;
    case 'a' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000363));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000139));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000140));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000141));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000142));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000143));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'b' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000144));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000161));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'c' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000145));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000146));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000147));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000148));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000152));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'd' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000149));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000150));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000151));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000325));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000326));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000359));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000366));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000372));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000373));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    case 'e' :
      lcrzo_epr(shared_lcrzoex_helpmode_cat_init(&cat, language, level));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000153));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_add(&cat, lcrzoex_000351));
      lcrzo_epr(shared_lcrzoex_helpmode_cat_close(&cat, levels, &toolnumber));
      break;
    }
    break;
    
  case 'o' :
    lcrzo_epr(lcrzo_uint32_init_stdin((language==LCRZO_GLOBAL_LANG_FR)?
				      "Entrez votre numero d'outil":
				      "Enter your tool number", 
				      1, 500, 1, &toolnumber));
    break;
    
  }

  if (ptoolnumber!=NULL) *ptoolnumber=toolnumber;
  return(LCRZO_ERR_OK);
}


/*-------------------------------------------------------------*/
/* this function classify and describes tools.
   this helps users to choose an tool */
int lcrzoex_helpchoice(lcrzo_conststring progname)
{ lcrzo_int8 levels[10];
  lcrzo_uint32 toolnumber;
  lcrzo_int16 language;

  /* get the current language */
  lcrzo_epr(lcrzo_global_get_language(&language));

  /* check if user has admin privileges */
  lcrzo_epr(shared_misc_checkadmin(language));

  if ( language==LCRZO_GLOBAL_LANG_FR )
  { puts("Ces outils ont ete crees avec la bibliotheque lcrzo.");
  }
  else
  { puts("These tools were created with the network library lcrzo.");
  }

  /* loop through menus */
  levels[0]='-';
  levels[1]='\0';
  toolnumber=0;
  while ( levels[0] && (toolnumber==0) )
  { lcrzo_epr(lcrzoex_helpchoice_tool_list(levels, &toolnumber));
  }
  if (levels[0]=='\0') return(LCRZO_ERR_OK);

  /* display */
  lcrzoex_displayusage(progname, toolnumber);

  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int lcrzoex_displayusage(lcrzo_conststring progname,
			 lcrzo_uint32 toolnumber)
{ lcrzo_string pn;
  lcrzo_int16 language;

  /* get the current language */
  lcrzo_epr(lcrzo_global_get_language(&language));

  /* display usage */
  if ( language==LCRZO_GLOBAL_LANG_FR )
    printf("\n---------- Voici comment utiliser cet outil :\n");
  else 
    printf("\n---------- Here is how to use this tool :\n");

  /* create a string containing "progname tool_number" */
  lcrzo_epr(lcrzo_string_initm_text(progname, &pn));
  lcrzo_epr(lcrzo_string_appendm_text(" ", &pn));
  lcrzo_epr(lcrzo_string_appendm_int(toolnumber, "%d", &pn));

  /* print infos about this tool */
  if ( toolnumber>=1 && toolnumber<=50 )
  { lcrzo_epr(lcrzoex__00001_infos_print(pn, toolnumber));
  }
  else if ( toolnumber>=51 && toolnumber<=100 )
  { lcrzo_epr(lcrzoex__00002_infos_print(pn, toolnumber));
  }
  else if ( toolnumber>=101 && toolnumber<=150 )
  { lcrzo_epr(lcrzoex__00003_infos_print(pn, toolnumber));
  }
  else if ( toolnumber>=151 && toolnumber<=200 )
  { lcrzo_epr(lcrzoex__00004_infos_print(pn, toolnumber));
  }
  else if ( toolnumber>=201 && toolnumber<=250 )
  { lcrzo_epr(lcrzoex__00005_infos_print(pn, toolnumber));
  }
  else if ( toolnumber>=251 && toolnumber<=300 )
  { lcrzo_epr(lcrzoex__00006_infos_print(pn, toolnumber));
  }
  else if ( toolnumber>=301 && toolnumber<=350 )
  { lcrzo_epr(lcrzoex__00007_infos_print(pn, toolnumber));
  }
  else if ( toolnumber>=351 && toolnumber<=400 )
  { lcrzo_epr(lcrzoex__00008_infos_print(pn, toolnumber));
  }
  else
  { shared_lcrzoex_unknowntool_print(toolnumber);
    lcrzo_epr(lcrzo_string_free2(&pn));
    return(LCRZOEX_ERR_MISC_BADTOOLUSAGE);
  }
  lcrzo_epr(lcrzo_string_free2(&pn));

  return(LCRZO_ERR_OK);
}
