
/* include the library headers */
#include <lcrzo.h>
#include "lcrzoex.h"

/*-------------------------------------------------------------*/
/* set information about this example */
shared_lcrzoex_infos lcrzoex_000289=
{ /*reference*/     "lcrzoex", 289,
  /*version*/       1, 0,
  /*title*/         "ftp client listing a directory using control connection only",
  /*french title*/  "client ftp listant un repertoire en utilisant la connexion de controle uniquement",
  /*description*/   "",
  /*french desc.*/  "",
  /*usage*/         "sername serport directory user [passwd]",
  /*french usage*/  "nomserv portserv repertoire utilisateur [password]",
  /*usage example*/ "1.2.3.5 21 /etc \"joe\" \"mypass\"",
  /*fr. usage ex.*/ "1.2.3.5 21 /etc \"laurent\" \"maison\"",
  /*author*/        "Laurent"
};

/*-------------------------------------------------------------*/
/* function declarations */
int lcrzoex_000289_main(int argc, char *argv[]);

/*-------------------------------------------------------------*/
/* main function : you can rename it to "main", and then this file
   can be compiled alone. */
int lcrzoex_000289_main(int argc, char *argv[])
{ lcrzo_sock sockcontrol;
  lcrzo_list listdir, listfile, listfilelink, listdirlink;
  lcrzo_data data;
  lcrzo_int32 datasize, count, i;
  lcrzo_uint32 filesize;
  lcrzo_ipl serveripl;
  lcrzo_uint16 serverport;
  lcrzo_string pwd;
  lcrzo_int16 language;

  lcrzo_init();
  if ( argc<5 )
  { /* print usage */
    lcrzo_epr(shared_lcrzoex_infos_print(lcrzoex_000289, argv[0]));
    return(LCRZOEX_ERR_MISC_BADTOOLUSAGE);
  }
  lcrzo_epr(lcrzo_global_get_language(&language));

  /* initialize IP addresses */
  lcrzo_epr(shared_para_ipl_init_dst(argv[1], &serveripl));

  /* initialize ports */
  lcrzo_epr(shared_para_port_init_dst(argv[2], 21, &serverport));

  /* initialize control connection */
  lcrzo_epr(lcrzo_sock_tcpcli_real(serveripl, serverport, &sockcontrol));

  /* first, we connect */
  if (argc>5)
  { lcrzo_epr(lcrzo_string_initm_text(argv[5], &pwd));
  }
  else
  { lcrzo_epr(lcrzo_string_initm_text_passwd("Passwd", "", &pwd));
  }
  lcrzo_epr(shared_ftp_login(&sockcontrol, argv[4], pwd));
  lcrzo_epr(lcrzo_string_free2(&pwd));

  /* we send a 'STAT' */
  lcrzo_epr(shared_ftp_cmd_stat(&sockcontrol, argv[3], &listfile, &listdir,
				&listfilelink, &listdirlink));

  /* display files */
  lcrzo_epr(lcrzo_list_count(&listfile, &count));
  if ( language==LCRZO_GLOBAL_LANG_FR )
    puts("Fichiers");
  else
    puts("Files");
  for ( i=1 ; i<=count ; i++ )
  { lcrzo_epr(lcrzo_datalist_valuem_pos(&listfile, i, &filesize, 
					&data, &datasize));
    data[datasize]='\0';
    printf("  %s ", data);
    lcrzo_int32_print("(", filesize, "%d", ")\n");
    lcrzo_epr(lcrzo_data_free2(&data));
  }
  lcrzo_epr(lcrzo_list_close(&listfile));

  /* display directories */
  lcrzo_epr(lcrzo_list_count(&listdir, &count));
  if ( language==LCRZO_GLOBAL_LANG_FR )
    puts("Repertoires");
  else
    puts("Directories");
  for ( i=1 ; i<=count ; i++ )
  { lcrzo_epr(lcrzo_datalist_valuem_pos(&listdir, i, NULL, 
					&data, &datasize));
    data[datasize]='\0';
    printf("  %s\n", data);
    lcrzo_epr(lcrzo_data_free2(&data));
  }
  lcrzo_epr(lcrzo_list_close(&listdir));

  /* display files */
  lcrzo_epr(lcrzo_list_count(&listfilelink, &count));
  if ( language==LCRZO_GLOBAL_LANG_FR )
    puts("Liens vers des fichiers");
  else
    puts("Links to files");
  for ( i=1 ; i<=count ; i++ )
  { lcrzo_epr(lcrzo_datalist_valuem_pos(&listfilelink, i, &filesize, 
					&data, &datasize));
    data[datasize]='\0';
    printf("  %s ---> %s ", data, data+strlen((lcrzo_string)data)+1);
    lcrzo_int32_print("(", filesize, "%d", ")\n");
    lcrzo_epr(lcrzo_data_free2(&data));
  }
  lcrzo_epr(lcrzo_list_close(&listfilelink));

  /* display directories */
  lcrzo_epr(lcrzo_list_count(&listdirlink, &count));
  if ( language==LCRZO_GLOBAL_LANG_FR )
    puts("Liens vers des repertoires");
  else
    puts("Links to directories");
  for ( i=1 ; i<=count ; i++ )
  { lcrzo_epr(lcrzo_datalist_valuem_pos(&listdirlink, i, NULL, 
					&data, &datasize));
    data[datasize]='\0';
    printf("  %s ---> %s\n", data, data+strlen((lcrzo_string)data)+1);
    lcrzo_epr(lcrzo_data_free2(&data));
  }
  lcrzo_epr(lcrzo_list_close(&listdirlink));

  /* then, we send a 'QUIT' */
  lcrzo_epr(shared_ftp_cmd_quit(&sockcontrol));

  /* close the socket */
  lcrzo_epr(lcrzo_sock_close(&sockcontrol));

  lcrzo_close();
  return (LCRZO_ERR_OK);
}
