/*
		                 LCRZOEX
                             Network toolbox
             Copyright(c) 1999,2000,2001,2002 Laurent Constantin
                                  -----

  Main server    : http://www.laurentconstantin.com/
  Backup servers : http://go.to/laurentconstantin/
                   http://laurentconstantin.est-la.com/
                   http://laurentconstantin.free.fr/
                   http://membres.lycos.fr/lauconstantin/
  [my current email address is on the web servers]

                                  -----
  This file is part of Lcrzoex.

  Lcrzoex is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Lcrzoex is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details (http://www.gnu.org/).

------------------------------------------------------------------------
*/

#include <lcrzo.h>
#include "../lcrzoex.h"

/*-------------------------------------------------------------*/
/*en print title of an tool */
/*fr affiche le titre d'un outil */
int shared_lcrzoex_title_print(shared_lcrzoex_infos infos)
{ lcrzo_int16 language;

  lcrzo_uint32_print("", infos.refvalue, "% 6d", " -");
  lcrzo_er(lcrzo_global_get_language(&language));
  if (language==LCRZO_GLOBAL_LANG_FR)
  { printf(" %s\n", infos.title_fr);
  }
  else
  { printf(" %s\n", infos.title_en);
  }

  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
/*en print information about an tool */
/*fr affiche les informations sur un outil */
int shared_lcrzoex_infos_print(shared_lcrzoex_infos infos,
			       lcrzo_conststring progname)
{ lcrzo_int16 language;

  lcrzo_er(lcrzo_global_get_language(&language));
  /* check if user has admin privileges */
  lcrzo_epr(shared_misc_checkadmin(language));

  printf("Reference    : %s_", infos.refname);
  lcrzo_uint32_print("", infos.refvalue, "%06d", ", ");
  if (language==LCRZO_GLOBAL_LANG_FR)
  { printf("version (de cet outil)");
  }
  else
  { printf("version (of this tool)");
  }
  printf(" %d.%02d\n", infos.majorversion, infos.minorversion);
  if (language==LCRZO_GLOBAL_LANG_FR)
  { printf("Titre        : %s\n", infos.title_fr);
    if ( strlen(infos.description_fr) )
      printf("Description  : %s\n", infos.description_fr);
    if ( strlen(infos.author) )
      printf("Auteur       : %s\n", infos.author);
    printf("Usage        : %s %s\n", progname, infos.usage_fr);
    printf("Exemple      : %s %s\n", progname, infos.usageex_fr);
  }
  else
  { printf("Title        : %s\n", infos.title_en);
    if ( strlen(infos.description_en) )
      printf("Description  : %s\n", infos.description_en);
    if ( strlen(infos.author) )
      printf("Author       : %s\n", infos.author);
    printf("Usage        : %s %s\n", progname, infos.usage_en);
    printf("Example      : %s %s\n", progname, infos.usageex_en);
  }

  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
/*en redirect an old tool */
/*fr redirige un ancien outil, vers un nouvel outil*/
int shared_lcrzoex_redirect_print(shared_lcrzoex_infos old,
				  shared_lcrzoex_infos newi)
{ lcrzo_int16 language;
  lcrzo_er(lcrzo_global_get_language(&language));
  if (language==LCRZO_GLOBAL_LANG_FR)
  { printf("** L'outil :\n");
  }
  else
  { printf("** The tool :\n");
  }
  printf("**   Reference  : %s_", old.refname);
  lcrzo_uint32_print("", old.refvalue, "%06d", "\n");
  printf("**   Version    : %d.%02d\n", old.majorversion, old.minorversion);
  if (language==LCRZO_GLOBAL_LANG_FR)
  { printf("** a ete remplace par :\n");
  }
  else
  { printf("** was superseded by :\n");
  }
  printf("**   Reference  : %s_", newi.refname);
  lcrzo_uint32_print("", newi.refvalue, "%06d", "\n");
  printf("**   Version    : %d.%02d\n", newi.majorversion, newi.minorversion);
  
  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int shared_lcrzoex_unknowntool_print(lcrzo_uint32 toolnumber)
{ lcrzo_int16 language;

  lcrzo_epr(lcrzo_global_get_language(&language));
  if ( language==LCRZO_GLOBAL_LANG_FR )
  { lcrzo_uint32_print("Outil '", toolnumber, "%d", "' inconnu.\n");
    lcrzo_uint32_print("L'outil numero ", toolnumber, "%d",
		       " est peut etre disponible ");
    printf("dans une version recente de lcrzoex.\n"); 
  }
  else
  { lcrzo_uint32_print("Tool '", toolnumber, "%d", "' unknown.\n");
    lcrzo_uint32_print("Tool number ", toolnumber, "%d",
		       " is perhaps only available ");
    printf("in a newer version of lcrzoex.\n"); 
  }

  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
typedef struct {
  lcrzo_uint32 toolnumber;
  lcrzo_int8 c;
} shared_priv_lcrzoex_helpmode_tool;

/*-------------------------------------------------------------*/
int shared_lcrzoex_helpmode_cat_init(shared_lcrzoex_helpmode_cat *pcat,
				     lcrzo_int16 language,
				     lcrzo_int16 level)
{
  pcat->language=language;
  pcat->level=level;
  pcat->c='a';
  lcrzo_epr(lcrzo_list_init(&pcat->list, 
			    sizeof(shared_priv_lcrzoex_helpmode_tool),
			    NULL));

  if ( pcat->language==LCRZO_GLOBAL_LANG_FR )
  { printf("\n++++++++++ Plusieurs outils sont disponibles dans cette categorie :\n");
    printf(" 0 - quitter lcrzoex\n");
    printf(" 1 - revenir au menu principal\n");
    printf(" 2 - revenir a la categorie precedente\n");
  }
  else 
  { printf("\n++++++++++ Several tools are available in this category :\n");
    printf(" 0 - leave lcrzoex\n");  
    printf(" 1 - go back to the main menu\n");  
    printf(" 2 - go back to the previous category\n");  
  }

  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int shared_lcrzoex_helpmode_cat_add(shared_lcrzoex_helpmode_cat *pcat,
				    shared_lcrzoex_infos infos)
{ shared_priv_lcrzoex_helpmode_tool hmt;

  printf(" %c -", pcat->c);
  lcrzo_uint32_print("", infos.refvalue, "% 4d", ":");
  if (pcat->language==LCRZO_GLOBAL_LANG_FR)
  { printf("%s\n", infos.title_fr);
  }
  else
  { printf("%s\n", infos.title_en);
  }

  hmt.toolnumber=infos.refvalue;
  hmt.c=pcat->c;
  lcrzo_epr(lcrzo_list_add_pos(&pcat->list, -1, &hmt));

  pcat->c++;
  if (pcat->c=='z'+1) pcat->c='A';
  if (pcat->c=='Z'+1) return(LCRZO_ERR_IEINTERNALERROR);

  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int shared_lcrzoex_helpmode_cat_close(shared_lcrzoex_helpmode_cat *pcat,
				      lcrzo_string levels, 
				      lcrzo_uint32 *ptoolnumber)
{ shared_priv_lcrzoex_helpmode_tool hmt;
  lcrzo_uint8 choice, i;
  lcrzo_string str;
  lcrzo_int32 count, j;
  
  lcrzo_epr(lcrzo_string_initm_text("012", &str));
  if ( pcat->c>='a' && pcat->c<='z'+1 )
  { for ( i='a' ; i<pcat->c ; i++ )
    { lcrzo_epr(lcrzo_string_appendm_char(i, 1, &str));
    }
  }
  else
  { for ( i='a' ; i<='z' ; i++ )
    { lcrzo_epr(lcrzo_string_appendm_char(i, 1, &str));
    }
    for ( i='A' ; i<pcat->c ; i++ )
    { lcrzo_epr(lcrzo_string_appendm_char(i, 1, &str));
    }
  }

  lcrzo_epr(lcrzo_stdin_char((pcat->language==LCRZO_GLOBAL_LANG_FR)?
			     "Selectionnez un outil":
			     "Select a tool", 
			     (lcrzo_constdata)str, 'a', &choice));
  lcrzo_er(lcrzo_string_free2(&str));
  if (choice=='0') 
  { levels[0]='\0';
  }
  else if (choice=='1') 
  { levels[1]='\0';
  }
  else if (choice=='2') 
  { levels[pcat->level]='\0';
  }
  else
  { lcrzo_epr(lcrzo_list_count(&pcat->list, &count));
    for ( j=1 ; j<=count ; j++ )
    { lcrzo_epr(lcrzo_list_value_pos(&pcat->list, j, &hmt));
      if ( hmt.c==choice )
      { if (ptoolnumber!=NULL) *ptoolnumber=hmt.toolnumber;
        return(LCRZO_ERR_OK);
      }
    }
    printf("Char %c was not found in list\n", choice);
    return(LCRZO_ERR_IEINTERNALERROR);
  }
  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int shared_lcrzoex_helpmode_catheader_init(shared_lcrzoex_helpmode_catheader *pcatheader,
					   lcrzo_int16 language,
					   lcrzo_int16 level)
{
  pcatheader->language=language;
  pcatheader->level=level;
  pcatheader->c='a';

  if ( pcatheader->language==LCRZO_GLOBAL_LANG_FR )
  { printf("\n********** Plusieurs sous-categories sont disponibles :\n");
    printf(" 0 - quitter lcrzoex\n");
    printf(" 1 - revenir au menu principal\n");
    printf(" 2 - revenir a la categorie precedente\n");
  }
  else 
  { printf("\n********** Several sub-categories are available :\n");
    printf(" 0 - leave lcrzoex\n");  
    printf(" 1 - go back to the main menu\n");  
    printf(" 2 - go back to the previous category\n");  
  }
  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int shared_lcrzoex_helpmode_catheader_add(shared_lcrzoex_helpmode_catheader *pcatheader,
					   lcrzo_conststring frstr,
					   lcrzo_conststring enstr)
{
  if ( pcatheader->language==LCRZO_GLOBAL_LANG_FR )
  { printf(" %c - %s\n", pcatheader->c, frstr);
  }
  else 
  { printf(" %c - %s\n", pcatheader->c, enstr);  
  }

  pcatheader->c++;
  if (pcatheader->c=='z'+1) return(LCRZO_ERR_IEINTERNALERROR);
  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int shared_lcrzoex_helpmode_catheader_close(shared_lcrzoex_helpmode_catheader *pcatheader,
					    lcrzo_string levels)
{ lcrzo_uint8 choice, i;
  lcrzo_string str;

  lcrzo_epr(lcrzo_string_initm_text("012", &str));
  for ( i='a' ; i<pcatheader->c ; i++ )
  { lcrzo_epr(lcrzo_string_appendm_char(i, 1, &str));
  }
  lcrzo_epr(lcrzo_stdin_char((pcatheader->language==LCRZO_GLOBAL_LANG_FR)?
			     "Entrez une sous-categorie":
			     "Enter a sub-category", 
			     (lcrzo_constdata)str, 'a', &choice));
  lcrzo_er(lcrzo_string_free2(&str));
  if (choice=='0') 
  { levels[0]='\0';
  }
  else if (choice=='1') 
  { levels[1]='\0';
  }
  else if (choice=='2') 
  { levels[pcatheader->level-1]='\0';
  }
  else
  { levels[pcatheader->level]=choice;
    levels[pcatheader->level+1]='\0'; 
  }
  return(LCRZO_ERR_OK);
}

/*-------------------------------------------------------------*/
int shared_lcrzoex_helpmode_mainmenu(lcrzo_int16 language,
				     lcrzo_string levels)
{ lcrzo_uint8 choice;
  char c;

  c='a';
  if ( language==LCRZO_GLOBAL_LANG_FR )
  { printf("\n########## MENU PRINCIPAL\n");
    printf(" 0 - quitter lcrzoex\n");
    printf(" %c - outils simples a utiliser (nouveaux utilisateurs, commencer ici)\n", c++);
    printf(" %c - obtient des informations\n", c++);
    printf(" %c - sniffe et sauve des paquets\n", c++);
    printf(" %c - affiche et rejoue des paquets sauves\n", c++);
    printf(" %c - spoof Ethernet et IP\n", c++);
    printf(" %c - clients udp\n", c++);
    printf(" %c - clients tcp\n", c++);
    printf(" %c - serveurs udp\n", c++);
    printf(" %c - serveurs tcp\n", c++);
    printf(" %c - routeurs et ponts\n", c++);
    printf(" %c - utilitaires pour administrateurs\n", c++);
    printf(" %c - serveur d'administration a distance\n", c++);
    printf(" %c - utilitaires malicieux\n", c++);
    printf(" %c - utilitaires divers\n", c++);
    printf(" %c - affiche l'usage d'un outil lorsque l'on connait son numero\n", c++);
  }
  else
  { printf("\n########## MAIN MENU\n");
    printf(" 0 - quit lcrzoex\n");
    printf(" %c - easy tools (new users, start here)\n", c++);
    printf(" %c - obtains information\n", c++);
    printf(" %c - sniff and save packets\n", c++);
    printf(" %c - display and resend saved packets\n", c++);
    printf(" %c - Ethernet and IP spoof\n", c++);
    printf(" %c - udp clients\n", c++);
    printf(" %c - tcp clients\n", c++);
    printf(" %c - udp servers\n", c++);
    printf(" %c - tcp servers\n", c++);
    printf(" %c - routers and bridges\n", c++);
    printf(" %c - administrators utilities\n", c++);
    printf(" %c - remote administration server\n", c++);
    printf(" %c - malicious utilities\n", c++);
    printf(" %c - miscellaneous utilities\n", c++);
    printf(" %c - display usage of a tool, when its number is known\n", c++);
  }
  /* get the user's choice */
  lcrzo_epr(lcrzo_stdin_char((language==LCRZO_GLOBAL_LANG_FR)?
			     "Entrez une categorie":
			     "Enter a category", 
			     (lcrzo_constdata)"0abcdefghijklmno",
			     'a', &choice));
  if (choice=='0')
    levels[0]='\0';
  else 
  { levels[1]=choice;
    levels[2]='\0'; 
  }

  return(LCRZO_ERR_OK);
}

